"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConsoleLogger = exports.ConsoleLogger = void 0;
var contracts_1 = require("./contracts");
var ConsoleLogger = /** @class */ (function () {
    function ConsoleLogger(context) {
        this.context = context;
    }
    ConsoleLogger.prototype.formatMessage = function (message, level, context) {
        var msg = '[' + contracts_1.LogLevel[level].toUpperCase() + ']';
        if (context && context.app) {
            msg += ' ' + context.app + ': ';
        }
        return msg + message;
    };
    ConsoleLogger.prototype.log = function (level, message, context) {
        var _a;
        if (level < ((_a = this.context) === null || _a === void 0 ? void 0 : _a.level))
            return;
        switch (level) {
            case contracts_1.LogLevel.Debug:
                console.debug(this.formatMessage(message, contracts_1.LogLevel.Debug, context), context);
                break;
            case contracts_1.LogLevel.Info:
                console.info(this.formatMessage(message, contracts_1.LogLevel.Info, context), context);
                break;
            case contracts_1.LogLevel.Warn:
                console.warn(this.formatMessage(message, contracts_1.LogLevel.Warn, context), context);
                break;
            case contracts_1.LogLevel.Error:
                console.error(this.formatMessage(message, contracts_1.LogLevel.Error, context), context);
                break;
            case contracts_1.LogLevel.Fatal:
            default:
                console.error(this.formatMessage(message, contracts_1.LogLevel.Fatal, context), context);
                break;
        }
    };
    ConsoleLogger.prototype.debug = function (message, context) {
        this.log(contracts_1.LogLevel.Debug, message, Object.assign({}, this.context, context));
    };
    ConsoleLogger.prototype.info = function (message, context) {
        this.log(contracts_1.LogLevel.Info, message, Object.assign({}, this.context, context));
    };
    ConsoleLogger.prototype.warn = function (message, context) {
        this.log(contracts_1.LogLevel.Warn, message, Object.assign({}, this.context, context));
    };
    ConsoleLogger.prototype.error = function (message, context) {
        this.log(contracts_1.LogLevel.Error, message, Object.assign({}, this.context, context));
    };
    ConsoleLogger.prototype.fatal = function (message, context) {
        this.log(contracts_1.LogLevel.Fatal, message, Object.assign({}, this.context, context));
    };
    return ConsoleLogger;
}());
exports.ConsoleLogger = ConsoleLogger;
function buildConsoleLogger(context) {
    return new ConsoleLogger(context);
}
exports.buildConsoleLogger = buildConsoleLogger;
