"use strict";
/// <reference types="@nextcloud/typings" />
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoggerBuilder = void 0;
var auth_1 = require("@nextcloud/auth");
var contracts_1 = require("./contracts");
/**
 * @notExported
 */
var LoggerBuilder = /** @class */ (function () {
    function LoggerBuilder(factory) {
        this.context = {};
        this.factory = factory;
    }
    /** Set the app name within the logging context */
    LoggerBuilder.prototype.setApp = function (appId) {
        this.context.app = appId;
        return this;
    };
    /** Set the logging level within the logging context */
    LoggerBuilder.prototype.setLogLevel = function (level) {
        this.context.level = level;
        return this;
    };
    /** Set the user id within the logging context
     * @see {@link detectUser}
    */
    LoggerBuilder.prototype.setUid = function (uid) {
        this.context.uid = uid;
        return this;
    };
    /** Detect the currently logged in user and set the user id within the logging context */
    LoggerBuilder.prototype.detectUser = function () {
        var user = (0, auth_1.getCurrentUser)();
        if (user !== null) {
            this.context.uid = user.uid;
        }
        return this;
    };
    /** Detect and use logging level configured in nextcloud config */
    LoggerBuilder.prototype.detectLogLevel = function () {
        var self = this;
        // Use arrow function to prevent undefined `this` within event handler
        var onLoaded = function () {
            var _a, _b, _c;
            if (document.readyState === "complete" || (document.readyState === "interactive" && window.OC !== undefined)) {
                // Up to, including, nextcloud 24 the loglevel was not exposed
                self.context.level = ((_b = (_a = window.OC) === null || _a === void 0 ? void 0 : _a.config) === null || _b === void 0 ? void 0 : _b.loglevel) !== undefined ? window.OC.config.loglevel : contracts_1.LogLevel.Warn;
                // Override loglevel if we are in debug mode
                if ((_c = window.OC) === null || _c === void 0 ? void 0 : _c.debug) {
                    self.context.level = contracts_1.LogLevel.Debug;
                }
                document.removeEventListener("readystatechange", onLoaded);
            }
            else {
                document.addEventListener("readystatechange", onLoaded);
            }
        };
        onLoaded();
        return this;
    };
    /** Build a logger using the logging context and factory */
    LoggerBuilder.prototype.build = function () {
        if (this.context.level === undefined) {
            // No logging level set manually, use the configured one
            this.detectLogLevel();
        }
        return this.factory(this.context);
    };
    return LoggerBuilder;
}());
exports.LoggerBuilder = LoggerBuilder;
